netapp_ontap.models.application_component_application API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved.

# Module `netapp_ontap.models.application_component_application`

Copyright © 2020 NetApp Inc. All rights reserved.

## Classes

`class ApplicationComponentApplicationSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the ApplicationComponentApplication object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `links GET`

    The links field of the application_component_application.

  `name GET`

    Application name

  `uuid GET`

    The application UUID. Valid in URL.